==> blackchocobo_1.9.910-0~201907232153~ubuntu18.10.1.tar.xz: recipe/ff7tk/widgets/MetadataCreator.h <==
/****************************************************************************/
//    copyright 2012 - 2016 Chris Rizzitello <sithlord48@gmail.com>         //
//                                                                          //
//    This file is part of Black Chocobo.                                   //
//                                                                          //
//    Black Chocobo is free software: you can redistribute it and/or modify //
//    it under the terms of the GNU General Public License as published by  //
//    the Free Software Foundation, either version 3 of the License, or     //
//    (at your option) any later version.                                   //
//                                                                          //
//    Black Chocobo is distributed in the hope that it will be useful,      //
//    but WITHOUT ANY WARRANTY; without even the implied warranty of        //
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          //
//    GNU General Public License for more details.                          //
/****************************************************************************/
/*~~~~~~~~~~~Includes~~~~~~~~*/

#ifndef METADATACREATOR_H
#define METADATACREATOR_H

#include <QtWidgets>
#include "../data/FF7Save.h"

class MetadataCreator : public QDialog
{
    Q_OBJECT
public:
    explicit MetadataCreator(QWidget *parent = nullptr, FF7Save *ff7save = nullptr);
private slots:
    void initDisplay();
    void on_buttonBox_accepted();

private:
    QVBoxLayout *makeLineLayout();
    //Data Parts
    bool load;
    FF7Save *ff7;
    QStringList InFiles;
    QString OutPath;
    QString UserID;
    QPushButton *btnOk = nullptr;
    QPushButton *btnCancel = nullptr;
};

#endif // METADATACREATOR_H

==> blackchocobo_1.10.0-0~202008041320~ubuntu18.04.1.tar.xz: recipe/ff7tk/widgets/MetadataCreator.h <==
/****************************************************************************/
//    copyright 2012 - 2020 Chris Rizzitello <sithlord48@gmail.com>         //
//                                                                          //
//    This file is part of Black Chocobo.                                   //
//                                                                          //
//    Black Chocobo is free software: you can redistribute it and/or modify //
//    it under the terms of the GNU General Public License as published by  //
//    the Free Software Foundation, either version 3 of the License, or     //
//    (at your option) any later version.                                   //
//                                                                          //
//    Black Chocobo is distributed in the hope that it will be useful,      //
//    but WITHOUT ANY WARRANTY; without even the implied warranty of        //
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         //
//    GNU General Public License for more details.                          //
/****************************************************************************/
#pragma once

#include <QDialog>

#include "../data/FF7SaveInfo.h"

class FF7Save;
class QDialogButtonBox;
class QVBoxLayout;

class MetadataCreator : public QDialog
{
    Q_OBJECT
public:
    explicit MetadataCreator(QWidget *parent = nullptr, FF7Save *ff7save = nullptr);
private slots:
    void initDisplay();
    void accepted();

private:
    QString getOpenFileName(QWidget  *parent = nullptr, const QString &title = QString(), const QString &path = QString(), const QString &nameFilters = QString(), const QString &initSelection = QString());
    QString getExistingDirectory(QWidget *parent = nullptr, const QString &title = QString(), const QString &path = QString(), const QString &initSelection = QString());
    QVBoxLayout *makeLineLayout();
    //Data Parts
    bool load;
    FF7Save *ff7;
    QStringList InFiles;
    QString OutPath;
    QString UserID;
    QDialogButtonBox *btnBox = nullptr;
};
